@@ -16,7 +16,6 @@
 
 */
 
-#include <osmium/handler.hpp>
 #include <osmium/handler/node_locations_for_ways.hpp>
 #include <osmium/index/map/all.hpp>
 #include <osmium/io/any_input.hpp>
@@ -26,8 +25,11 @@
 #include <chrono>
 #include <cmath>
 #include <cstdlib>
+#include <exception>
 #include <iostream>
 #include <limits>
+#include <memory>
+#include <ratio>
 #include <string>
 
 using static_index_type = osmium::index::map::SparseMemArray<osmium::unsigned_object_id_type, osmium::Location>;
