@@ -9,13 +9,13 @@
 #include <string>
 
 TEST_CASE("GeoJSON point geometry") {
-    osmium::geom::GeoJSONFactory<> factory;
+    const osmium::geom::GeoJSONFactory<> factory;
     const std::string json{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(std::string{"{\"type\":\"Point\",\"coordinates\":[3.2,4.2]}"} == json);
 }
 
 TEST_CASE("GeoJSON empty point geometry") {
-    osmium::geom::GeoJSONFactory<> factory;
+    const osmium::geom::GeoJSONFactory<> factory;
     REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), osmium::invalid_location);
 }
 
@@ -117,7 +117,7 @@ TEST_CASE("GeoJSON area geometry") {
         REQUIRE(std::distance(area.cbegin(), area.cend()) == 2);
         REQUIRE(area.subitems<osmium::OuterRing>().size() == area.num_rings().first);
 
-        std::string json{factory.create_multipolygon(area)};
+        const std::string json{factory.create_multipolygon(area)};
         REQUIRE(std::string{"{\"type\":\"MultiPolygon\",\"coordinates\":[[[[3.2,4.2],[3.5,4.7],[3.6,4.9],[3.2,4.2]]]]}"} == json);
     }
 
@@ -129,7 +129,7 @@ TEST_CASE("GeoJSON area geometry") {
         REQUIRE(area.subitems<osmium::OuterRing>().size() == area.num_rings().first);
         REQUIRE(area.subitems<osmium::InnerRing>().size() == area.num_rings().second);
 
-        std::string json{factory.create_multipolygon(area)};
+        const std::string json{factory.create_multipolygon(area)};
         REQUIRE(std::string{"{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0.1,0.1],[9.1,0.1],[9.1,9.1],[0.1,9.1],[0.1,0.1]],[[1,1],[8,1],[8,8],[1,8],[1,1]]]]}"} == json);
     }
 
@@ -165,7 +165,7 @@ TEST_CASE("GeoJSON area geometry") {
             ++outer_ring;
         }
 
-        std::string json{factory.create_multipolygon(area)};
+        const std::string json{factory.create_multipolygon(area)};
         REQUIRE(std::string{"{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0.1,0.1],[9.1,0.1],[9.1,9.1],[0.1,9.1],[0.1,0.1]],[[1,1],[4,1],[4,4],[1,4],[1,1]],[[5,5],[5,7],[7,7],[5,5]]],[[[10,10],[11,10],[11,11],[10,11],[10,10]]]]}"} == json);
     }
 
