@@ -11,5 +11,11 @@ TEST_CASE("nwr_array") {
     REQUIRE(a(osmium::item_type::node) == 1);
     REQUIRE(a(osmium::item_type::way) == 2);
     REQUIRE(a(osmium::item_type::relation) == 3);
+
+    auto it = a.cbegin();
+    REQUIRE(*it++ == 1);
+    REQUIRE(*it++ == 2);
+    REQUIRE(*it++ == 3);
+    REQUIRE(it == a.cend());
 }
 
