@@ -10,21 +10,26 @@
 #include <cstring>
 #include <initializer_list>
 #include <string>
+#include <utility>
 #include <vector>
 
 namespace oid = osmium::io::detail;
 
+namespace {
+
 // From C++20 we need to handle unicode literals differently
 #ifdef __cpp_char8_t
-static const char* u8cast(const char8_t *s) noexcept {
+const char* u8cast(const char8_t *s) noexcept {
     return reinterpret_cast<const char*>(s);
 }
 #else
-static const char* u8cast(const char *s) noexcept {
+const char* u8cast(const char *s) noexcept {
     return s;
 }
 #endif
 
+} // anonymous namespace
+
 TEST_CASE("Parse OPL: base exception") {
     const osmium::opl_error e{"foo"};
     REQUIRE(e.data == nullptr);
@@ -256,6 +261,8 @@ TEST_CASE("Parse OPL: parse string") {
 
 }
 
+namespace {
+
 template <typename T = int64_t>
 T test_parse_int(const char* s) {
     const auto r = oid::opl_parse_int<T>(&s);
@@ -263,6 +270,8 @@ T test_parse_int(const char* s) {
     return r;
 }
 
+} // anonymous namespace
+
 TEST_CASE("Parse OPL: integer") {
     REQUIRE(test_parse_int("0x") == 0);
     REQUIRE(test_parse_int("-0x") == 0);
@@ -1188,6 +1197,8 @@ public:
 
 }; // class lbl_tester
 
+namespace {
+
 void check_lbl(const std::initializer_list<std::string>& in,
                const std::initializer_list<std::string>& out) {
     lbl_tester tester{in, out};
@@ -1195,6 +1206,8 @@ void check_lbl(const std::initializer_list<std::string>& in,
     tester.check();
 }
 
+} // anonymous namespace
+
 TEST_CASE("line_by_line for OPL parser 1") {
     check_lbl({""}, {});
 }
