@@ -1,5 +1,9 @@
 #include "catch.hpp"
 
+// This file contains the same tests as test_location_extra.cpp, except those
+// tests specific to the location extra bit. OSMIUM_LOCATION_WITH_EXTRA_BIT is
+// not set.
+
 #include <osmium/osm/location.hpp>
 
 #include <cstdint>
@@ -161,9 +165,9 @@ TEST_CASE("Location hash") {
     if (sizeof(size_t) == 8) {
         REQUIRE(std::hash<osmium::Location>{}({0, 0}) == 0);
         REQUIRE(std::hash<osmium::Location>{}({0, 1}) == 1);
-        const int64_t a = std::hash<osmium::Location>{}({1, 0});
+        const auto a = std::hash<osmium::Location>{}({1, 0});
         REQUIRE(a == 0x100000000);
-        const int64_t b = std::hash<osmium::Location>{}({1, 1});
+        const auto b = std::hash<osmium::Location>{}({1, 1});
         REQUIRE(b == 0x100000001);
     } else {
         REQUIRE(std::hash<osmium::Location>{}({0, 0}) == 0);
